@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  */
 
@@ -33,17 +33,25 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <glib-object.h>
-#include <gio/gio.h>
+#define DBUS_API_SUBJECT_TO_CHANGE
+#include <dbus/dbus-glib.h>
+#include <dbus/dbus-glib-lowlevel.h>
 
 #include "gdm-settings.h"
+#include "gdm-settings-glue.h"
 
 #include "gdm-settings-desktop-backend.h"
 
+#define GDM_DBUS_PATH         "/org/gnome/DisplayManager"
+#define GDM_SETTINGS_DBUS_PATH GDM_DBUS_PATH "/Settings"
+#define GDM_SETTINGS_DBUS_NAME "org.gnome.DisplayManager.Settings"
+
 #define GDM_SETTINGS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GDM_TYPE_SETTINGS, GdmSettingsPrivate))
 
 struct GdmSettingsPrivate
 {
-        GList *backends;
+        DBusGConnection    *connection;
+        GdmSettingsBackend *backend;
 };
 
 enum {
@@ -72,6 +80,10 @@ gdm_settings_error_quark (void)
         return ret;
 }
 
+/*
+dbus-send --system --print-reply --dest=org.gnome.DisplayManager /org/gnome/DisplayManager/Settings org.gnome.DisplayManager.Settings.GetValue string:"xdmcp/Enable"
+*/
+
 gboolean
 gdm_settings_get_value (GdmSettings *settings,
                         const char  *key,
@@ -80,28 +92,15 @@ gdm_settings_get_value (GdmSettings *settings,
 {
         GError  *local_error;
         gboolean res;
-        GList   *l;
 
         g_return_val_if_fail (GDM_IS_SETTINGS (settings), FALSE);
         g_return_val_if_fail (key != NULL, FALSE);
 
         local_error = NULL;
-
-        for (l = settings->priv->backends; l; l = g_list_next (l)) {
-                GdmSettingsBackend *backend = l->data;
-
-                if (local_error) {
-                        g_error_free (local_error);
-                        local_error = NULL;
-                }
-
-                res = gdm_settings_backend_get_value (backend,
-                                                      key,
-                                                      value,
-                                                      &local_error);
-                if (res)
-                        break;
-        }
+        res = gdm_settings_backend_get_value (settings->priv->backend,
+                                              key,
+                                              value,
+                                              &local_error);
         if (! res) {
                 g_propagate_error (error, local_error);
         }
@@ -109,6 +108,10 @@ gdm_settings_get_value (GdmSettings *settings,
         return res;
 }
 
+/*
+dbus-send --system --print-reply --dest=org.gnome.DisplayManager /org/gnome/DisplayManager/Settings org.gnome.DisplayManager.Settings.SetValue string:"xdmcp/Enable" string:"false"
+*/
+
 gboolean
 gdm_settings_set_value (GdmSettings *settings,
                         const char  *key,
@@ -117,7 +120,6 @@ gdm_settings_set_value (GdmSettings *settings,
 {
         GError  *local_error;
         gboolean res;
-        GList   *l;
 
         g_return_val_if_fail (GDM_IS_SETTINGS (settings), FALSE);
         g_return_val_if_fail (key != NULL, FALSE);
@@ -125,23 +127,10 @@ gdm_settings_set_value (GdmSettings *settings,
         g_debug ("Setting value %s", key);
 
         local_error = NULL;
-
-        for (l = settings->priv->backends; l; l = g_list_next (l)) {
-                GdmSettingsBackend *backend = l->data;
-
-                if (local_error) {
-                        g_error_free (local_error);
-                        local_error = NULL;
-                }
-
-                res = gdm_settings_backend_set_value (backend,
-                                                      key,
-                                                      value,
-                                                      &local_error);
-                if (res)
-                        break;
-        }
-
+        res = gdm_settings_backend_set_value (settings->priv->backend,
+                                              key,
+                                              value,
+                                              &local_error);
         if (! res) {
                 g_propagate_error (error, local_error);
         }
@@ -149,6 +138,30 @@ gdm_settings_set_value (GdmSettings *settings,
         return res;
 }
 
+static gboolean
+register_settings (GdmSettings *settings)
+{
+        GError *error = NULL;
+
+        error = NULL;
+        settings->priv->connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
+        if (settings->priv->connection == NULL) {
+                if (error != NULL) {
+                        g_critical ("error getting system bus: %s", error->message);
+                        g_error_free (error);
+                }
+                exit (1);
+        }
+
+        dbus_g_connection_register_g_object (settings->priv->connection, GDM_SETTINGS_DBUS_PATH, G_OBJECT (settings));
+
+        return TRUE;
+}
+
+/*
+dbus-send --system --print-reply --dest=org.gnome.DisplayManager /org/gnome/DisplayManager/Settings org.freedesktop.DBus.Introspectable.Introspect
+*/
+
 static void
 gdm_settings_class_init (GdmSettingsClass *klass)
 {
@@ -171,6 +184,8 @@ gdm_settings_class_init (GdmSettingsClass *klass)
                               G_TYPE_STRING);
 
         g_type_class_add_private (klass, sizeof (GdmSettingsPrivate));
+
+        dbus_g_object_type_install_info (GDM_TYPE_SETTINGS, &dbus_glib_gdm_settings_object_info);
 }
 
 static void
@@ -181,35 +196,25 @@ backend_value_changed (GdmSettingsBackend *backend,
                        GdmSettings        *settings)
 {
         g_debug ("Emitting value-changed %s %s %s", key, old_value, new_value);
-
-        /* proxy it to internal listeners */
-        g_signal_emit (settings, signals [VALUE_CHANGED], 0, key, old_value, new_value);
+        /* just proxy it */
+        g_signal_emit (settings,
+                       signals [VALUE_CHANGED],
+                       0,
+                       key,
+                       old_value,
+                       new_value);
 }
 
 static void
 gdm_settings_init (GdmSettings *settings)
 {
-        GList *l;
-        GdmSettingsBackend *backend;
-
         settings->priv = GDM_SETTINGS_GET_PRIVATE (settings);
 
-        backend = gdm_settings_desktop_backend_new (GDM_CUSTOM_CONF);
-        if (backend)
-                settings->priv->backends = g_list_prepend (NULL, backend);
-
-        backend = gdm_settings_desktop_backend_new (GDM_RUNTIME_CONF);
-        if (backend)
-                settings->priv->backends = g_list_prepend (settings->priv->backends, backend);
-
-        for (l = settings->priv->backends; l; l = g_list_next (l)) {
-                backend = l->data;
-
-                g_signal_connect (backend,
-                                  "value-changed",
-                                  G_CALLBACK (backend_value_changed),
-                                  settings);
-        }
+        settings->priv->backend = gdm_settings_desktop_backend_new ();
+        g_signal_connect (settings->priv->backend,
+                          "value-changed",
+                          G_CALLBACK (backend_value_changed),
+                          settings);
 }
 
 static void
@@ -224,11 +229,9 @@ gdm_settings_finalize (GObject *object)
 
         g_return_if_fail (settings->priv != NULL);
 
-        g_list_foreach (settings->priv->backends, (GFunc) g_object_unref, NULL);
-        g_list_free (settings->priv->backends);
-        settings->priv->backends = NULL;
-
-        settings_object = NULL;
+        if (settings->priv->backend != NULL) {
+                g_object_unref (settings->priv->backend);
+        }
 
         G_OBJECT_CLASS (gdm_settings_parent_class)->finalize (object);
 }
@@ -239,7 +242,17 @@ gdm_settings_new (void)
         if (settings_object != NULL) {
                 g_object_ref (settings_object);
         } else {
+                gboolean res;
+
                 settings_object = g_object_new (GDM_TYPE_SETTINGS, NULL);
+                g_object_add_weak_pointer (settings_object,
+                                           (gpointer *) &settings_object);
+                res = register_settings (settings_object);
+                if (! res) {
+                        g_warning ("Unable to register settings");
+                        g_object_unref (settings_object);
+                        return NULL;
+                }
         }
 
         return GDM_SETTINGS (settings_object);
