@@ -117,6 +117,9 @@ on_greeter_session_stop (GdmGreeterSession *greeter,
                          GdmFactorySlave   *slave)
 {
         g_debug ("GdmFactorySlave: Greeter stopped");
+
+        g_object_unref (GDM_FACTORY_SLAVE (slave)->priv->greeter);
+        GDM_FACTORY_SLAVE (slave)->priv->greeter = NULL;
 }
 
 static void
@@ -671,12 +674,14 @@ static gboolean
 gdm_factory_slave_run (GdmFactorySlave *slave)
 {
         char    *display_name;
+        char    *seat_id;
         char    *auth_file;
         gboolean display_is_local;
 
         g_object_get (slave,
                       "display-is-local", &display_is_local,
                       "display-name", &display_name,
+                      "display-seat-id", &seat_id,
                       "display-x11-authority-file", &auth_file,
                       NULL);
 
@@ -685,7 +690,7 @@ gdm_factory_slave_run (GdmFactorySlave *slave)
         if (display_is_local) {
                 gboolean res;
 
-                slave->priv->server = gdm_server_new (display_name, auth_file);
+                slave->priv->server = gdm_server_new (display_name, seat_id, auth_file);
                 g_signal_connect (slave->priv->server,
                                   "exited",
                                   G_CALLBACK (on_server_exited),
@@ -847,8 +852,6 @@ gdm_factory_slave_stop (GdmSlave *slave)
 
         if (GDM_FACTORY_SLAVE (slave)->priv->greeter != NULL) {
                 gdm_welcome_session_stop (GDM_WELCOME_SESSION (GDM_FACTORY_SLAVE (slave)->priv->greeter));
-                g_object_unref (GDM_FACTORY_SLAVE (slave)->priv->greeter);
-                GDM_FACTORY_SLAVE (slave)->priv->greeter = NULL;
         }
 
         if (GDM_FACTORY_SLAVE (slave)->priv->server != NULL) {
