@@ -1344,28 +1344,9 @@ gdm_slave_get_primary_session_id_for_user_from_systemd (GdmSlave   *slave,
         }
 
         for (i = 0; sessions[i] != NULL; i++) {
-                char *type;
                 gboolean is_active;
-                gboolean is_x11;
                 uid_t other;
 
-                res = sd_session_get_type (sessions[i], &type);
-
-                if (res < 0) {
-                        g_warning ("GdmSlave: could not fetch type of session '%s': %s",
-                                   sessions[i], strerror (-res));
-                        continue;
-                }
-
-                is_x11 = g_strcmp0 (type, "x11") == 0;
-                g_free (type);
-
-                /* Only migrate to graphical sessions
-                 */
-                if (!is_x11) {
-                        continue;
-                }
-
                 /* Always give preference to non-active sessions,
                  * so we migrate when we can and don't when we can't
                  */
@@ -1658,7 +1639,7 @@ session_unlock_for_systemd (GdmSlave   *slave,
 
         dbus_error_init (&error);
 
-        message = dbus_message_new_method_call ("org.freedesktop.login1",
+        message = dbus_message_new_method_call ("org.freedesktop.login",
                                                 "/org/freedesktop/login1",
                                                 "org.freedesktop.login1.Manager",
                                                 "UnlockSession");
@@ -1736,7 +1717,7 @@ session_unlock (GdmSlave   *slave,
                 const char *ssid)
 {
 
-        g_debug ("Unlocking session %s", ssid);
+        g_debug ("ConsoleKit: Unlocking session %s", ssid);
 
 #ifdef WITH_SYSTEMD
         if (sd_booted () > 0) {
