@@ -42,7 +42,6 @@
 #include <dbus/dbus-glib-lowlevel.h>
 
 #include "gdm-common.h"
-#include "ck-connector.h"
 
 #include "gdm-session.h"
 #include "gdm-session-direct.h"
@@ -78,7 +77,6 @@ struct GdmWelcomeSessionPrivate
         char           *server_dbus_path;
         char           *server_dbus_interface;
         char           *server_env_var_name;
-        gboolean        register_ck_session;
 
         char           *server_address;
 };
@@ -98,8 +96,7 @@ enum {
         PROP_COMMAND,
         PROP_SERVER_DBUS_PATH,
         PROP_SERVER_DBUS_INTERFACE,
-        PROP_SERVER_ENV_VAR_NAME,
-        PROP_REGISTER_CK_SESSION,
+        PROP_SERVER_ENV_VAR_NAME
 };
 
 enum {
@@ -314,7 +311,6 @@ build_welcome_environment (GdmWelcomeSession *welcome_session,
                 seat_id = welcome_session->priv->x11_display_seat_id +
                         strlen ("/org/freedesktop/ConsoleKit/");
 
-                g_hash_table_insert (hash, g_strdup ("GCONF_DEFAULT_SOURCE_PATH"), g_strdup (GCONF_DEFAULTPATH));
                 g_hash_table_insert (hash, g_strdup ("GDM_SEAT_ID"), g_strdup (seat_id));
         }
 
@@ -422,30 +418,6 @@ spawn_child_setup (SpawnChildData *data)
                 _exit (1);
         }
 
-        if (pwent->pw_dir != NULL) {
-                struct stat statbuf;
-                const char *seat_id;
-                char       *gconf_dir;
-                int         r;
-
-                seat_id = data->seat_id + strlen ("/org/freedesktop/ConsoleKit/");
-                gconf_dir = g_strdup_printf ("%s/%s", pwent->pw_dir, seat_id);
-
-                /* Verify per-seat gconf directory exists, create if needed */
-                r = g_stat (gconf_dir, &statbuf);
-                if (r < 0) {
-                        g_debug ("Making per-seat gconf directory %s", gconf_dir);
-                        g_mkdir (gconf_dir, S_IRWXU | S_IXGRP | S_IRGRP);
-                        g_chmod (gconf_dir, S_IRWXU | S_IXGRP | S_IRGRP);
-                        res = chown (gconf_dir, pwent->pw_uid, grent->gr_gid);
-                        if (res == -1) {
-                                g_warning ("GdmWelcomeSession: Error setting owner of per-seat gconf directory: %s",
-                                           g_strerror (errno));
-                        }
-                }
-                g_free (gconf_dir);
-        }
-
         g_debug ("GdmWelcomeSession: Setting up run time dir %s", data->runtime_dir);
         g_mkdir (data->runtime_dir, 0755);
         res = chown (data->runtime_dir, pwent->pw_uid, pwent->pw_gid);
@@ -852,6 +824,7 @@ gdm_welcome_session_start (GdmWelcomeSession *welcome_session)
                                                                               welcome_session->priv->x11_display_name,
                                                                               welcome_session->priv->x11_display_hostname,
                                                                               welcome_session->priv->x11_display_device,
+                                                                              welcome_session->priv->x11_display_seat_id,
                                                                               welcome_session->priv->x11_authority_file,
                                                                               welcome_session->priv->x11_display_is_local));
 
@@ -1039,13 +1012,6 @@ _gdm_welcome_session_set_server_env_var_name (GdmWelcomeSession *welcome_session
         welcome_session->priv->server_env_var_name = g_strdup (name);
 }
 
-static void
-_gdm_welcome_session_set_register_ck_session (GdmWelcomeSession *welcome_session,
-                                              gboolean           val)
-{
-        welcome_session->priv->register_ck_session = val;
-}
-
 static void
 gdm_welcome_session_set_property (GObject      *object,
                                   guint         prop_id,
@@ -1093,9 +1059,6 @@ gdm_welcome_session_set_property (GObject      *object,
         case PROP_SERVER_DBUS_INTERFACE:
                 _gdm_welcome_session_set_server_dbus_interface (self, g_value_get_string (value));
                 break;
-        case PROP_REGISTER_CK_SESSION:
-                _gdm_welcome_session_set_register_ck_session (self, g_value_get_boolean (value));
-                break;
         case PROP_SERVER_ENV_VAR_NAME:
                 _gdm_welcome_session_set_server_env_var_name (self, g_value_get_string (value));
                 break;
@@ -1155,9 +1118,6 @@ gdm_welcome_session_get_property (GObject    *object,
         case PROP_SERVER_DBUS_INTERFACE:
                 g_value_set_string (value, self->priv->server_dbus_interface);
                 break;
-        case PROP_REGISTER_CK_SESSION:
-                g_value_set_boolean (value, self->priv->register_ck_session);
-                break;
         case PROP_SERVER_ENV_VAR_NAME:
                 g_value_set_string (value, self->priv->server_env_var_name);
                 break;
@@ -1279,13 +1239,6 @@ gdm_welcome_session_class_init (GdmWelcomeSessionClass *klass)
                                                               "command",
                                                               NULL,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-        g_object_class_install_property (object_class,
-                                         PROP_REGISTER_CK_SESSION,
-                                         g_param_spec_boolean ("register-ck-session",
-                                                               NULL,
-                                                               NULL,
-                                                               FALSE,
-                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
         signals [STARTED] =
                 g_signal_new ("started",
                               G_OBJECT_CLASS_TYPE (object_class),
